@@ -1,6 +1,9 @@
 import datetime
+import faulthandler
 import unittest
 
+faulthandler.enable()  # to debug seg faults and timeouts
+
 import cf
 
 
@@ -12,9 +15,9 @@ logger = cf.logging.getLogger(log_name)
 
 
 class dummyClass:
-    '''Dummy class acting as container to test methods as proper instance
-       methods, mirroring their context in the codebase.
-    '''
+    """Dummy class acting as container to test methods as proper
+    instance methods, mirroring their context in the codebase."""
+
     def __init__(self, verbose=None):
         self.verbose = verbose
 
@@ -24,72 +27,71 @@ class dummyClass:
         self.warning_message = "Best pay attention to this!"
 
     def func_2(self, good_kwarg=True, traceback=False, bad_kwarg=False):
-        '''Dummy function, otherwise trivial, where a True boolean passed as
-           a traceback keyword argument will ultimately raise an error.
-        '''
+        """Dummy function, otherwise trivial, where a True boolean
+        passed as a traceback keyword argument will ultimately raise an
+        error."""
         if traceback:
             cf.functions._DEPRECATION_ERROR_KWARGS(
-                self, 'another_func', traceback=True)
+                self, "another_func", traceback=True
+            )
         return good_kwarg
 
-    @cf.decorators._deprecated_kwarg_check('traceback')
-    def decorated_func_2(
-            self, good_kwarg=True, traceback=False):
-        '''Dummy function equivalent to 'func_2', but a decorator manages the
-           logic to raise the error on use of a deprecated keyword argument.
-        '''
+    @cf.decorators._deprecated_kwarg_check("traceback")
+    def decorated_func_2(self, good_kwarg=True, traceback=False):
+        """Dummy function equivalent to 'func_2', but a decorator
+        manages the logic to raise the error on use of a deprecated
+        keyword argument."""
         return good_kwarg
 
     # Not testing 'bad_kwarg' here other than to the extent that it does not
     # stop 'traceback from causing the expected deprecation-related error.
-    @cf.decorators._deprecated_kwarg_check('traceback', 'bad_kwarg')
+    @cf.decorators._deprecated_kwarg_check("traceback", "bad_kwarg")
     def multikwarg_decorated_func_2(
-            self, good_kwarg=True, traceback=False, bad_kwarg=False):
-        '''Dummy function equivalent to 'func_2', but a decorator manages the
-           logic to raise the error on use of a deprecated keyword argument.
-        '''
+        self, good_kwarg=True, traceback=False, bad_kwarg=False
+    ):
+        """Dummy function equivalent to 'func_2', but a decorator
+        manages the logic to raise the error on use of a deprecated
+        keyword argument."""
         return good_kwarg
 
     @cf.decorators._manage_log_level_via_verbose_attr
     def decorated_logging_func(self):
-        '''Dummy method to test _manage_log_level_via_verbose_attr.
+        """Dummy method to test _manage_log_level_via_verbose_attr.
 
-        In particular, to test it interfaces with self.verbose correctly.
-        '''
+        In particular, to test it interfaces with self.verbose
+        correctly.
+
+        """
         logger.debug(self.debug_message)
         logger.detail(self.detail_message)
         logger.info(self.info_message)
         logger.warning(self.warning_message)
 
-# --- End: class
-
 
 class DecoratorsTest(unittest.TestCase):
-    '''Test decorators module.
+    """Test decorators module.
 
     These are unit tests on the self-contained decorators applied to an
-    artificial, trivial & not cf-python specific class, so for the cases where
-    decorators are imported directly from cf, there is no need to duplicate
-    such tests which are already in the cf test suite.
-    '''
+    artificial, trivial & not cf-python specific class, so for the cases
+    where decorators are imported directly from cf, there is no need to
+    duplicate such tests which are already in the cf test suite.
+
+    """
+
     def setUp(self):
         self.test_only = []
 
     def test_deprecated_kwarg_check(self):
-        if self.test_only and inspect.stack()[0][3] not in self.test_only:
-            return
-
         test_class = dummyClass()
 
         # Test without (or with default) deprecated keyword argument
         res_1 = test_class.func_2(good_kwarg="good")
         res_2 = test_class.decorated_func_2(good_kwarg="good")
-        res_3 = test_class.func_2(
-            good_kwarg="good", traceback=False)
-        res_4 = test_class.decorated_func_2(
-            good_kwarg="good", traceback=False)
-        res_5 = test_class.multikwarg_decorated_func_2(
-            good_kwarg="good", traceback=False)
+        res_3 = test_class.func_2(good_kwarg="good", traceback=False)
+        res_4 = test_class.decorated_func_2(good_kwarg="good", traceback=False)
+        test_class.multikwarg_decorated_func_2(
+            good_kwarg="good", traceback=False
+        )
         self.assertEqual(res_1, res_2)
         self.assertEqual(res_2, "good")
         self.assertEqual(res_3, res_4)
@@ -99,30 +101,27 @@ class DecoratorsTest(unittest.TestCase):
         with self.assertRaises(cf.functions.DeprecationError):
             test_class.func_2(good_kwarg="good", traceback=True)
         with self.assertRaises(cf.functions.DeprecationError):
-            test_class.decorated_func_2(
-                good_kwarg="good", traceback=True)
+            test_class.decorated_func_2(good_kwarg="good", traceback=True)
         with self.assertRaises(cf.functions.DeprecationError):
             test_class.func_2(traceback=True, bad_kwarg="bad")
         with self.assertRaises(cf.functions.DeprecationError):
             test_class.multikwarg_decorated_func_2(
-                traceback=True, bad_kwarg="bad")
+                traceback=True, bad_kwarg="bad"
+            )
 
     def test_manage_log_level_via_verbose_attr(self):
-        if self.test_only and inspect.stack()[0][3] not in self.test_only:
-            return
-
         # Order of decreasing severity/verbosity is crucial to one test below
-        levels = ['WARNING', 'INFO', 'DETAIL', 'DEBUG']
+        levels = ["WARNING", "INFO", "DETAIL", "DEBUG"]
 
         # Note we test assertions on the root logger object, which is the
         # one output overall at runtime, but the specific module logger name
         # should be registered within the log message:
         example_class = dummyClass()
         log_message = [
-            'WARNING:{}:{}'.format(log_name, example_class.warning_message),
-            'INFO:{}:{}'.format(log_name, example_class.info_message),
-            'DETAIL:{}:{}'.format(log_name, example_class.detail_message),
-            'DEBUG:{}:{}'.format(log_name, example_class.debug_message)
+            "WARNING:{}:{}".format(log_name, example_class.warning_message),
+            "INFO:{}:{}".format(log_name, example_class.info_message),
+            "DETAIL:{}:{}".format(log_name, example_class.detail_message),
+            "DEBUG:{}:{}".format(log_name, example_class.debug_message),
         ]
 
         for level in levels:
@@ -147,7 +146,7 @@ class DecoratorsTest(unittest.TestCase):
 
             # Highest verbosity case (note -1 == 'DEBUG', highest verbosity):
             # all messages should appear, regardless of global log_level:
-            for attr in (-1, 'DEBUG', 'debug', 'Debug', 'DeBuG'):
+            for attr in (-1, "DEBUG", "debug", "Debug", "DeBuG"):
                 test_class.verbose = attr
                 with self.assertLogs(level=cf.log_level().value) as catch:
                     test_class.decorated_logging_func()
@@ -157,12 +156,12 @@ class DecoratorsTest(unittest.TestCase):
             # Lowest verbosity case ('WARNING' / 1) excluding special case of
             # 'DISABLE' (see note above): only warning messages should appear,
             # regardless of global log_level value set:
-            for attr in (1, 'WARNING', 'warning', 'Warning', 'WaRning'):
+            for attr in (1, "WARNING", "warning", "Warning", "WaRning"):
                 test_class.verbose = attr
                 with self.assertLogs(level=cf.log_level().value) as catch:
                     test_class.decorated_logging_func()
                     for msg in log_message:
-                        if msg.split(":")[0] == 'WARNING':
+                        if msg.split(":")[0] == "WARNING":
                             self.assertIn(msg, catch.output)
                         else:
                             self.assertNotIn(msg, catch.output)
@@ -174,7 +173,7 @@ class DecoratorsTest(unittest.TestCase):
             with self.assertLogs(level=cf.log_level().value) as catch:
                 test_class.decorated_logging_func()
                 for msg in log_message:
-                    if msg.split(":")[0] == 'DEBUG':
+                    if msg.split(":")[0] == "DEBUG":
                         self.assertNotIn(msg, catch.output)
                     else:
                         self.assertIn(msg, catch.output)
@@ -185,33 +184,32 @@ class DecoratorsTest(unittest.TestCase):
             # Special 'DISABLE' (0) case: note this needs to be last as we
             # reset the log_level to it but need to use 'NOTSET' for the
             # assertLogs level, which sends all log messages through:
-            for attr in (0, 'DISABLE', 'disable', 'Disable', 'DisAblE'):
+            for attr in (0, "DISABLE", "disable", "Disable", "DisAblE"):
                 test_class.verbose = attr
-                with self.assertLogs(level='NOTSET') as catch:
+                with self.assertLogs(level="NOTSET") as catch:
                     # Note: get 'AssertionError' if don't log anything at all,
                     # so to avoid this and allow check for disabled logging,
                     # first log something then disable and check that no other
                     # messages emerge:
                     logger.info(
-                        "Purely to keep 'assertLog' happy: see comment!")
-                    cf.log_level('DISABLE')
+                        "Purely to keep 'assertLog' happy: see comment!"
+                    )
+                    cf.log_level("DISABLE")
                     test_class.decorated_logging_func()
                     for msg in log_message:  # nothing else should be logged
                         self.assertNotIn(msg, catch.output)
 
             # verbose=0 should be equivalent in behaviour to verbose=0
             test_class.verbose = False
-            with self.assertLogs(level='NOTSET') as catch:
+            with self.assertLogs(level="NOTSET") as catch:
                 logger.info("Purely to keep 'assertLog' happy: see previous!")
                 test_class.decorated_logging_func()
                 for msg in log_message:  # nothing else should be logged
                     self.assertNotIn(msg, catch.output)
 
-# --- End: class
 
-
-if __name__ == '__main__':
-    print('Run date:', datetime.datetime.now())
+if __name__ == "__main__":
+    print("Run date:", datetime.datetime.now())
     cf.environment()
     print()
     unittest.main(verbosity=2)
