@@ -1,17 +1,22 @@
 import atexit
 import datetime
+import faulthandler
 import os
 import tempfile
 import unittest
 
+faulthandler.enable()  # to debug seg faults and timeouts
+
 import netCDF4
 
 import cf
 
 
 n_tmpfiles = 8
-tmpfiles = [tempfile.mkstemp('_test_groups.nc', dir=os.getcwd())[1]
-            for i in range(n_tmpfiles)]
+tmpfiles = [
+    tempfile.mkstemp("_test_groups.nc", dir=os.getcwd())[1]
+    for i in range(n_tmpfiles)
+]
 (
     ungrouped_file1,
     ungrouped_file2,
@@ -25,9 +30,7 @@ tmpfiles = [tempfile.mkstemp('_test_groups.nc', dir=os.getcwd())[1]
 
 
 def _remove_tmpfiles():
-    '''Remove temporary files created during tests.
-
-    '''
+    """Remove temporary files created during tests."""
     for f in tmpfiles:
         try:
             os.remove(f)
@@ -41,7 +44,7 @@ atexit.register(_remove_tmpfiles)
 class GroupsTest(unittest.TestCase):
     def setUp(self):
         # Disable log messages to silence expected warnings
-        cf.LOG_LEVEL('DISABLE')
+        cf.LOG_LEVEL("DISABLE")
         # Note: to enable all messages for given methods, lines or
         # calls (those without a 'verbose' option to do the same)
         # e.g. to debug them, wrap them (for methods, start-to-end
@@ -58,21 +61,22 @@ class GroupsTest(unittest.TestCase):
         grouped_file = grouped_file1
 
         # Add a second grid mapping
-        datum = cf.Datum(parameters={'earth_radius': 7000000})
+        datum = cf.Datum(parameters={"earth_radius": 7000000})
         conversion = cf.CoordinateConversion(
-            parameters={'grid_mapping_name': 'latitude_longitude'})
+            parameters={"grid_mapping_name": "latitude_longitude"}
+        )
 
         grid = cf.CoordinateReference(
             coordinate_conversion=conversion,
             datum=datum,
-            coordinates=['auxiliarycoordinate0', 'auxiliarycoordinate1']
+            coordinates=["auxiliarycoordinate0", "auxiliarycoordinate1"],
         )
 
         f.set_construct(grid)
 
-        grid0 = f.construct('grid_mapping_name:rotated_latitude_longitude')
-        grid0.del_coordinate('auxiliarycoordinate0')
-        grid0.del_coordinate('auxiliarycoordinate1')
+        grid0 = f.construct("grid_mapping_name:rotated_latitude_longitude")
+        grid0.del_coordinate("auxiliarycoordinate0")
+        grid0.del_coordinate("auxiliarycoordinate1")
 
         cf.write(f, ungrouped_file)
         g = cf.read(ungrouped_file, verbose=1)
@@ -83,13 +87,13 @@ class GroupsTest(unittest.TestCase):
         # ------------------------------------------------------------
         # Move the field construct to the /forecast/model group
         # ------------------------------------------------------------
-        g.nc_set_variable_groups(['forecast', 'model'])
+        g.nc_set_variable_groups(["forecast", "model"])
         cf.write(g, grouped_file)
 
-        nc = netCDF4.Dataset(grouped_file, 'r')
+        nc = netCDF4.Dataset(grouped_file, "r")
         self.assertIn(
             f.nc_get_variable(),
-            nc.groups['forecast'].groups['model'].variables
+            nc.groups["forecast"].groups["model"].variables,
         )
         nc.close()
 
@@ -102,24 +106,25 @@ class GroupsTest(unittest.TestCase):
         # in which we do this matters!
         # ------------------------------------------------------------
         for name in (
-                'longitude',  # Auxiliary coordinate
-                'latitude',  # Auxiliary coordinate
-                'long_name=Grid latitude name',  # Auxiliary coordinate
-                'measure:area',  # Cell measure
-                'surface_altitude',  # Domain ancillary
-                'air_temperature standard_error',  # Field ancillary
-                'grid_mapping_name:rotated_latitude_longitude',
-                'time',  # Dimension coordinate
-                'grid_latitude',  # Dimension coordinate
+            "longitude",  # Auxiliary coordinate
+            "latitude",  # Auxiliary coordinate
+            "long_name=Grid latitude name",  # Auxiliary coordinate
+            "measure:area",  # Cell measure
+            "surface_altitude",  # Domain ancillary
+            "air_temperature standard_error",  # Field ancillary
+            "grid_mapping_name:rotated_latitude_longitude",
+            "time",  # Dimension coordinate
+            "grid_latitude",  # Dimension coordinate
         ):
-            g.construct(name).nc_set_variable_groups(['forecast'])
+            g.construct(name).nc_set_variable_groups(["forecast"])
             cf.write(g, grouped_file, verbose=1)
 
             # Check that the variable is in the right group
-            nc = netCDF4.Dataset(grouped_file, 'r')
+            nc = netCDF4.Dataset(grouped_file, "r")
             self.assertIn(
                 f.construct(name).nc_get_variable(),
-                nc.groups['forecast'].variables)
+                nc.groups["forecast"].variables,
+            )
             nc.close()
 
             # Check that the field construct hasn't changed
@@ -130,17 +135,18 @@ class GroupsTest(unittest.TestCase):
         # ------------------------------------------------------------
         # Move bounds to the /forecast group
         # ------------------------------------------------------------
-        name = 'grid_latitude'
-        g.construct(name).bounds.nc_set_variable_groups(['forecast'])
+        name = "grid_latitude"
+        g.construct(name).bounds.nc_set_variable_groups(["forecast"])
         cf.write(g, grouped_file)
 
-        nc = netCDF4.Dataset(grouped_file, 'r')
+        nc = netCDF4.Dataset(grouped_file, "r")
         self.assertIn(
             f.construct(name).bounds.nc_get_variable(),
-            nc.groups['forecast'].variables)
+            nc.groups["forecast"].variables,
+        )
         nc.close()
 
-        h = cf.read(grouped_file, verbose='WARNING')
+        h = cf.read(grouped_file, verbose="WARNING")
         self.assertEqual(len(h), 1, repr(h))
         self.assertTrue(f.equals(h[0], verbose=2))
 
@@ -160,13 +166,13 @@ class GroupsTest(unittest.TestCase):
         # ------------------------------------------------------------
         # Move the field construct to the /forecast/model group
         # ------------------------------------------------------------
-        g.nc_set_variable_groups(['forecast', 'model'])
+        g.nc_set_variable_groups(["forecast", "model"])
         cf.write(g, grouped_file)
 
-        nc = netCDF4.Dataset(grouped_file, 'r')
+        nc = netCDF4.Dataset(grouped_file, "r")
         self.assertIn(
             f.nc_get_variable(),
-            nc.groups['forecast'].groups['model'].variables
+            nc.groups["forecast"].groups["model"].variables,
         )
         nc.close()
 
@@ -177,14 +183,14 @@ class GroupsTest(unittest.TestCase):
         # ------------------------------------------------------------
         # Move the geometry container to the /forecast group
         # ------------------------------------------------------------
-        g.nc_set_geometry_variable_groups(['forecast'])
+        g.nc_set_geometry_variable_groups(["forecast"])
         cf.write(g, grouped_file)
 
         # Check that the variable is in the right group
-        nc = netCDF4.Dataset(grouped_file, 'r')
+        nc = netCDF4.Dataset(grouped_file, "r")
         self.assertIn(
-            f.nc_get_geometry_variable(),
-            nc.groups['forecast'].variables)
+            f.nc_get_geometry_variable(), nc.groups["forecast"].variables
+        )
         nc.close()
 
         # Check that the field construct hasn't changed
@@ -195,14 +201,15 @@ class GroupsTest(unittest.TestCase):
         # ------------------------------------------------------------
         # Move a node coordinate variable to the /forecast group
         # ------------------------------------------------------------
-        g.construct('longitude').bounds.nc_set_variable_groups(['forecast'])
+        g.construct("longitude").bounds.nc_set_variable_groups(["forecast"])
         cf.write(g, grouped_file)
 
         # Check that the variable is in the right group
-        nc = netCDF4.Dataset(grouped_file, 'r')
+        nc = netCDF4.Dataset(grouped_file, "r")
         self.assertIn(
-            f.construct('longitude').bounds.nc_get_variable(),
-            nc.groups['forecast'].variables)
+            f.construct("longitude").bounds.nc_get_variable(),
+            nc.groups["forecast"].variables,
+        )
         nc.close()
 
         # Check that the field construct hasn't changed
@@ -213,16 +220,14 @@ class GroupsTest(unittest.TestCase):
         # ------------------------------------------------------------
         # Move a node count variable to the /forecast group
         # ------------------------------------------------------------
-        ncvar = g.construct('longitude').get_node_count().nc_get_variable()
-        g.nc_set_component_variable_groups('node_count', ['forecast'])
+        ncvar = g.construct("longitude").get_node_count().nc_get_variable()
+        g.nc_set_component_variable_groups("node_count", ["forecast"])
 
         cf.write(g, grouped_file)
 
         # Check that the variable is in the right group
-        nc = netCDF4.Dataset(grouped_file, 'r')
-        self.assertIn(
-            ncvar,
-            nc.groups['forecast'].variables)
+        nc = netCDF4.Dataset(grouped_file, "r")
+        self.assertIn(ncvar, nc.groups["forecast"].variables)
         nc.close()
 
         # Check that the field construct hasn't changed
@@ -234,17 +239,15 @@ class GroupsTest(unittest.TestCase):
         # Move a part node count variable to the /forecast group
         # ------------------------------------------------------------
         ncvar = (
-            g.construct('longitude').get_part_node_count().nc_get_variable()
+            g.construct("longitude").get_part_node_count().nc_get_variable()
         )
-        g.nc_set_component_variable_groups('part_node_count', ['forecast'])
+        g.nc_set_component_variable_groups("part_node_count", ["forecast"])
 
         cf.write(g, grouped_file)
 
         # Check that the variable is in the right group
-        nc = netCDF4.Dataset(grouped_file, 'r')
-        self.assertIn(
-            ncvar,
-            nc.groups['forecast'].variables)
+        nc = netCDF4.Dataset(grouped_file, "r")
+        self.assertIn(ncvar, nc.groups["forecast"].variables)
         nc.close()
 
         # Check that the field construct hasn't changed
@@ -255,16 +258,17 @@ class GroupsTest(unittest.TestCase):
         # ------------------------------------------------------------
         # Move interior ring variable to the /forecast group
         # ------------------------------------------------------------
-        g.nc_set_component_variable('interior_ring', 'interior_ring')
-        g.nc_set_component_variable_groups('interior_ring', ['forecast'])
+        g.nc_set_component_variable("interior_ring", "interior_ring")
+        g.nc_set_component_variable_groups("interior_ring", ["forecast"])
 
         cf.write(g, grouped_file)
 
         # Check that the variable is in the right group
-        nc = netCDF4.Dataset(grouped_file, 'r')
+        nc = netCDF4.Dataset(grouped_file, "r")
         self.assertIn(
-            f.construct('longitude').get_interior_ring().nc_get_variable(),
-            nc.groups['forecast'].variables)
+            f.construct("longitude").get_interior_ring().nc_get_variable(),
+            nc.groups["forecast"].variables,
+        )
         nc.close()
 
         # Check that the field construct hasn't changed
@@ -278,9 +282,9 @@ class GroupsTest(unittest.TestCase):
         ungrouped_file = ungrouped_file3
         grouped_file = grouped_file3
 
-        f.compress('indexed_contiguous', inplace=True)
-        f.data.get_count().nc_set_variable('count')
-        f.data.get_index().nc_set_variable('index')
+        f.compress("indexed_contiguous", inplace=True)
+        f.data.get_count().nc_set_variable("count")
+        f.data.get_index().nc_set_variable("index")
 
         cf.write(f, ungrouped_file, verbose=1)
         g = cf.read(ungrouped_file)[0]
@@ -289,48 +293,49 @@ class GroupsTest(unittest.TestCase):
         # ------------------------------------------------------------
         # Move the field construct to the /forecast/model group
         # ------------------------------------------------------------
-        g.nc_set_variable_groups(['forecast', 'model'])
+        g.nc_set_variable_groups(["forecast", "model"])
 
         # ------------------------------------------------------------
         # Move the count variable to the /forecast group
         # ------------------------------------------------------------
-        g.data.get_count().nc_set_variable_groups(['forecast'])
+        g.data.get_count().nc_set_variable_groups(["forecast"])
 
         # ------------------------------------------------------------
         # Move the index variable to the /forecast group
         # ------------------------------------------------------------
-        g.data.get_index().nc_set_variable_groups(['forecast'])
+        g.data.get_index().nc_set_variable_groups(["forecast"])
 
         # ------------------------------------------------------------
         # Move the coordinates that span the element dimension to the
         # /forecast group
         # ------------------------------------------------------------
-        name = 'altitude'
-        g.construct(name).nc_set_variable_groups(['forecast'])
+        name = "altitude"
+        g.construct(name).nc_set_variable_groups(["forecast"])
 
         # ------------------------------------------------------------
         # Move the sample dimension to the /forecast group
         # ------------------------------------------------------------
-        g.data.get_count().nc_set_sample_dimension_groups(['forecast'])
+        g.data.get_count().nc_set_sample_dimension_groups(["forecast"])
 
         cf.write(g, grouped_file, verbose=1)
 
-        nc = netCDF4.Dataset(grouped_file, 'r')
+        nc = netCDF4.Dataset(grouped_file, "r")
         self.assertIn(
             f.nc_get_variable(),
-            nc.groups['forecast'].groups['model'].variables
+            nc.groups["forecast"].groups["model"].variables,
         )
         self.assertIn(
             f.data.get_count().nc_get_variable(),
-            nc.groups['forecast'].variables
+            nc.groups["forecast"].variables,
         )
         self.assertIn(
             f.data.get_index().nc_get_variable(),
-            nc.groups['forecast'].variables
+            nc.groups["forecast"].variables,
         )
         self.assertIn(
-            f.construct('altitude').nc_get_variable(),
-            nc.groups['forecast'].variables)
+            f.construct("altitude").nc_get_variable(),
+            nc.groups["forecast"].variables,
+        )
         nc.close()
 
         h = cf.read(grouped_file, verbose=1)
@@ -352,36 +357,35 @@ class GroupsTest(unittest.TestCase):
         # ------------------------------------------------------------
         # Move the field construct to the /forecast/model group
         # ------------------------------------------------------------
-        g.nc_set_variable_groups(['forecast', 'model'])
+        g.nc_set_variable_groups(["forecast", "model"])
 
         # ------------------------------------------------------------
         # Move all data constructs to the /forecast group
         # ------------------------------------------------------------
         for construct in g.constructs.filter_by_data().values():
-            construct.nc_set_variable_groups(['forecast'])
+            construct.nc_set_variable_groups(["forecast"])
 
         # ------------------------------------------------------------
         # Move all coordinate bounds constructs to the /forecast group
         # ------------------------------------------------------------
-        for construct in g.coordinates.values():
+        for construct in g.coordinates().values():
             try:
-                construct.bounds.nc_set_variable_groups(['forecast'])
+                construct.bounds.nc_set_variable_groups(["forecast"])
             except ValueError:
                 pass
-        # --- End: for
 
         cf.write(g, grouped_file, verbose=1)
 
-        nc = netCDF4.Dataset(grouped_file, 'r')
+        nc = netCDF4.Dataset(grouped_file, "r")
         self.assertIn(
             f.nc_get_variable(),
-            nc.groups['forecast'].groups['model'].variables
+            nc.groups["forecast"].groups["model"].variables,
         )
 
         for key, construct in g.constructs.filter_by_data().items():
             self.assertIn(
                 f.constructs[key].nc_get_variable(),
-                nc.groups['forecast'].variables
+                nc.groups["forecast"].variables,
             )
 
         nc.close()
@@ -394,9 +398,9 @@ class GroupsTest(unittest.TestCase):
         # ------------------------------------------------------------
         # Move all the lat dimension to the /forecast group
         # ------------------------------------------------------------
-        key = g.domain_axis_key('latitude')
+        key = g.domain_axis_key("latitude")
         domain_axis = g.constructs[key]
-        domain_axis.nc_set_dimension_groups(['forecast'])
+        domain_axis.nc_set_dimension_groups(["forecast"])
 
         cf.write(g, grouped_file, verbose=1)
 
@@ -405,11 +409,9 @@ class GroupsTest(unittest.TestCase):
         h = h[0]
         self.assertTrue(f.equals(h, verbose=3))
 
-# --- End: class
 
-
-if __name__ == '__main__':
-    print('Run date:', datetime.datetime.now())
+if __name__ == "__main__":
+    print("Run date:", datetime.datetime.now())
     cf.environment()
     print()
     unittest.main(verbosity=2)
